@@ -3,7 +3,7 @@
  * @brief Implementation of the LfoScreen class
  *
  *
- *      Copyright 2009 - 2024 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2025 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -142,8 +142,13 @@ void LfoScreen::paintEvent(QPaintEvent*)
 
 void LfoScreen::emitMouseEvent(QMouseEvent *event, int pressed)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     mouseX = event->x();
     mouseY = event->y();
+#else
+    mouseX = event->position().x();
+    mouseY = event->position().y();
+#endif
     bool cl = false;
 
     mouseX = clip(mouseX, LFOSCR_HMARG, xMax, &cl);
