@@ -3,7 +3,7 @@
  * @brief Member definitions for the MainWindow top-level UI class.
  *
  *
- *      Copyright 2009 - 2024 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2025 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 
 static const char ABOUTMSG[] =
             "<html> <p><b><big>" APP_NAME " " PACKAGE_VERSION "</big></b></p>"
-            "<p>(C) 2009 - 2024 Frank Kober<br/>"
+            "<p>(C) 2009 - 2025 Frank Kober<br/>"
             "(C) 2011 Nedko Arnaudov<br/>"
             "(C) 2009 Guido Scholz<br/>"
             "(C) 2002-2003 Matthias Nagorni (SuSE AG Nuremberg)<br/></p>"
@@ -85,7 +85,7 @@ class MainWindow : public QMainWindow
     Engine *engine;
     MidiCCTable *midiCCTable;
     Prefs *prefs;
-    QString lastDir, filename;
+    QString lastDir, filename, platformName;
     QStringList patternNames, patternPresets;
     QStringList recentFiles;
     QDockWidget *logWindow, *grooveWindow, *passWindow, *globStoreWindow;
@@ -335,7 +335,8 @@ class MainWindow : public QMainWindow
 * @param p_alsamidi Start as ALSA MIDI client
 * @param *execName Name of the application's executable
 */
-    MainWindow(int p_portCount, bool p_alsamidi, char *execName);
+    MainWindow(int p_portCount, bool p_alsamidi, char *execName, 
+                                const QString & platform_name);
     ~MainWindow();
 
     bool jackFailed;
