@@ -3,7 +3,7 @@
  * @brief Member definitions for the MidiControl QWidget class.
  *
  *
- *      Copyright 2009 - 2024 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2025 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -25,9 +25,11 @@
 #define MIDICONTROL_H
 
 #include <QAction>
+#include <QActionGroup>
 #include <QSignalMapper>
 #include <QStringList>
 #include <QVector>
+#include <QWidget>
 #include <QXmlStreamWriter>
 
 #include <cstdio>
