@@ -3,7 +3,7 @@
  * @brief Implements the SeqWidget GUI class.
  *
  *
- *      Copyright 2009 - 2023 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2025 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -37,8 +37,7 @@ SeqWidget::SeqWidget(MidiSeq *p_midiSeq, GlobStore *p_globStore,
     bool compactStyle = p_prefs->compactStyle;
 #else
 SeqWidget::SeqWidget():
-    ModuleWidget("Seq:"),
-    midiSeq(NULL)
+    ModuleWidget("Seq:")
 {
     bool compactStyle = true;
 #endif
@@ -141,7 +140,7 @@ SeqWidget::SeqWidget():
 
     dispVert[0]->setChecked(true);
     dispVertIndex = 0;
-    connect(dispSignalMapper, SIGNAL(mapped(int)),
+    connect(dispSignalMapper, SIGNAL(mappedInt(int)),
              this, SLOT(updateDispVert(int)));
 
     velocity = new Slider(0, 127, 1, 8, 64, Qt::Horizontal,
@@ -176,7 +175,7 @@ SeqWidget::SeqWidget():
     sliderLayout->setRowStretch(5, 1);
     if (compactStyle) {
         sliderLayout->setSpacing(1);
-        sliderLayout->setMargin(2);
+        sliderLayout->setContentsMargins(2, 2, 2, 2);
     }
 
     QGridLayout *paramBoxLayout = new QGridLayout;
@@ -197,7 +196,7 @@ SeqWidget::SeqWidget():
     seqBoxLayout->addLayout(paramBoxLayout, 2, 0);
     seqBoxLayout->addLayout(sliderLayout, 2, 1);
     if (compactStyle) {
-        seqBoxLayout->setMargin(2);
+        seqBoxLayout->setContentsMargins(2, 2, 2, 2);
         seqBoxLayout->setSpacing(0);
     }
     seqBox->setLayout(seqBoxLayout);
@@ -299,28 +298,28 @@ void SeqWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
             }
         }
         
-        if (xml.isStartElement() && (xml.name() == "display")) {
+        if (xml.isStartElement() && (xml.name() == QString("display"))) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
                     break;
-                if (xml.name() == "vertical")
+                if (xml.name() == QString("vertical"))
                     setDispVert(xml.readElementText().toInt());
                 else skipXmlElement(xml);
             }
         }
 
-        else if (xml.isStartElement() && (xml.name() == "seqParams")) {
+        else if (xml.isStartElement() && (xml.name() == QString("seqParams"))) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
                     break;
-                if (xml.name() == "loopmode") {
+                if (xml.name() == QString("loopmode")) {
                     tmp = xml.readElementText().toInt();
                     loopBox->setCurrentIndex(tmp);
                     updateLoop(tmp);
                 }
-                else if (xml.name() == "resolution") {
+                else if (xml.name() == QString("resolution")) {
                     tmp = xml.readElementText().toInt();
                     if (qmaxVersion == "" && tmp < 5) {
                         tmp = mapOldSeqRes[tmp];
@@ -328,7 +327,7 @@ void SeqWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
                     resBox->setCurrentIndex(tmp);
                     updateRes(tmp);
                 }
-                else if (xml.name() == "size") {
+                else if (xml.name() == QString("size")) {
                     tmp = xml.readElementText().toInt();
                     if (qmaxVersion == "" && tmp < 10) {
                         tmp = mapOldSeqSize[tmp];
@@ -336,15 +335,15 @@ void SeqWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
                     sizeBox->setCurrentIndex(tmp);
                     updateSize(tmp);
                 }
-                else if (xml.name() == "velocity") {
+                else if (xml.name() == QString("velocity")) {
                     tmp = xml.readElementText().toInt();
                     velocity->setValue(tmp);
                     updateVelocity(tmp);
                 }
-                else if (xml.name() == "noteLength") {
+                else if (xml.name() == QString("noteLength")) {
                     notelength->setValue(xml.readElementText().toInt());
                 }
-                else if (xml.name() == "transp") {
+                else if (xml.name() == QString("transp")) {
                     tmp = xml.readElementText().toInt();
                     transpose->setValue(tmp);
                     updateTranspose(tmp);
@@ -352,33 +351,33 @@ void SeqWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
                 else skipXmlElement(xml);
             }
         }
-        else if (xml.isStartElement() && (xml.name() == "muteMask")) {
+        else if (xml.isStartElement() && (xml.name() == QString("muteMask"))) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
                     break;
-                if (xml.isStartElement() && (xml.name() == "data")) {
+                if (xml.isStartElement() && (xml.name() == QString("data"))) {
                     QByteArray tmpArray =
                             QByteArray::fromHex(xml.readElementText().toLatin1());
-                    for (int l1 = 0; l1 < tmpArray.count(); l1++) {
+                    for (int l1 = 0; l1 < tmpArray.length(); l1++) {
                         midiSeq->muteMask[l1] = tmpArray.at(l1);
                     }
-                    midiSeq->maxNPoints = tmpArray.count();
+                    midiSeq->maxNPoints = tmpArray.length();
                 }
                 else skipXmlElement(xml);
             }
         }
-        else if (xml.isStartElement() && (xml.name() == "sequence")) {
+        else if (xml.isStartElement() && (xml.name() == QString("sequence"))) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
                     break;
-                if (xml.isStartElement() && (xml.name() == "data")) {
+                if (xml.isStartElement() && (xml.name() == QString("data"))) {
                     QByteArray tmpArray =
                             QByteArray::fromHex(xml.readElementText().toLatin1());
                     int step = TPQN / midiSeq->res;
                     int lt = 0;
-                    for (int l1 = 0; l1 < tmpArray.count(); l1++) {
+                    for (int l1 = 0; l1 < tmpArray.length(); l1++) {
                         sample.data = tmpArray.at(l1);
                         sample.tick = lt;
                         sample.muted = midiSeq->muteMask[l1];
@@ -387,7 +386,7 @@ void SeqWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
                     }
                     updateWaveForm(0);
                 }
-                else if (xml.name() == "loopmarker") {
+                else if (xml.name() == QString("loopmarker")) {
                     tmp = xml.readElementText().toInt();
                     midiSeq->setLoopMarker(tmp);
                     screen->setLoopMarker(tmp);
@@ -408,7 +407,11 @@ void SeqWidget::readData(QXmlStreamReader& xml, const QString& qmaxVersion)
 
 void SeqWidget::updateNoteLength(int val)
 {
-    if (midiSeq) midiSeq->updateNoteLength(sliderToTickLen(val));
+#ifdef APPBUILD
+    midiSeq->updateNoteLength(sliderToTickLen(val));
+#else
+    (void)val;
+#endif
     modified = true;
 }
 
@@ -416,7 +419,7 @@ void SeqWidget::updateWaveForm(int val)
 {
     (void)val;
     modified = true;
-    if (!midiSeq) return;
+#ifdef APPBUILD
     std::vector<Sample> sdata;
     midiSeq->getData(&sdata);
 #if QT_VERSION <= QT_VERSION_CHECK(5,14,0)
@@ -425,15 +428,17 @@ void SeqWidget::updateWaveForm(int val)
     data=QVector<Sample>(sdata.begin(), sdata.end());
 #endif
     screen->updateData(data);
+#endif
 }
 
 void SeqWidget::setRecord(bool on)
 {
     recordMode = on;
     screen->setRecordMode(on);
-    if (!midiSeq) return;
+#ifdef APPBUILD
     midiSeq->setRecordMode(on);
     screen->setCurrentRecStep(midiSeq->currentRecStep);
+#endif
 }
 
 void SeqWidget::updateRes(int val)
@@ -441,7 +446,7 @@ void SeqWidget::updateRes(int val)
     if ((uint64_t)val >= sizeof(seqResValues)/sizeof(seqResValues[0])) return;
     resBoxIndex = val;
     modified = true;
-    if (!midiSeq) return;
+#ifdef APPBUILD
     midiSeq->res = seqResValues[val];
     midiSeq->resizeAll();
     std::vector<Sample> sdata;
@@ -453,6 +458,7 @@ void SeqWidget::updateRes(int val)
 #endif
     screen->setCurrentRecStep(midiSeq->currentRecStep);
     screen->updateData(data);
+#endif
 }
 
 void SeqWidget::updateSize(int val)
@@ -460,7 +466,7 @@ void SeqWidget::updateSize(int val)
     if ((uint64_t)val >= sizeof(seqSizeValues)/sizeof(seqSizeValues[0])) return;
     sizeBoxIndex = val;
     modified = true;
-    if (!midiSeq) return;
+#ifdef APPBUILD
     midiSeq->size = sizeBox->currentText().toInt();
     midiSeq->resizeAll();
     std::vector<Sample> sdata;
@@ -472,24 +478,37 @@ void SeqWidget::updateSize(int val)
 #endif
     screen->setCurrentRecStep(midiSeq->currentRecStep);
     screen->updateData(data);
+#endif
 }
 
 void SeqWidget::updateLoop(int val)
 {
     if (val > 6) return;
-    if (midiSeq) midiSeq->updateLoop(val);
+#ifdef APPBUILD
+    midiSeq->updateLoop(val);
+#else
+    (void)val;
+#endif
     modified = true;
 }
 
 void SeqWidget::updateVelocity(int val)
 {
-    if (midiSeq) midiSeq->updateVelocity(val);
+#ifdef APPBUILD
+    midiSeq->updateVelocity(val);
+#else
+    (void)val;
+#endif
     modified = true;
 }
 
 void SeqWidget::updateTranspose(int val)
 {
-    if (midiSeq) midiSeq->updateTranspose(val);
+#ifdef APPBUILD
+    midiSeq->updateTranspose(val);
+#else
+    (void)val;
+#endif
     modified = true;
 }
 
@@ -506,12 +525,11 @@ void SeqWidget::mouseEvent(double mouseX, double mouseY, int buttons, int presse
         screen->setLoopMarker(lm);
         screen->updateDraw();
     }
-    if (!midiSeq) {
-        emit mouseSig(mouseX, mouseY, buttons, pressed);
-    }
-    else {
-        midiSeq->mouseEvent(mouseX, mouseY, buttons, pressed);
-    }
+#ifdef APPBUILD
+    midiSeq->mouseEvent(mouseX, mouseY, buttons, pressed);
+#else
+    emit mouseSig(mouseX, mouseY, buttons, pressed);
+#endif
 
     modified = true;
 }
@@ -524,7 +542,9 @@ void SeqWidget::setDispVert(int mode)
 void SeqWidget::updateDispVert(int mode)
 {
     dispVertIndex = mode;
-    if (midiSeq) midiSeq->updateDispVert(mode);
+#ifdef APPBUILD
+    midiSeq->updateDispVert(mode);
+#endif
     screen->updateDispVert(mode);
     modified = true;
 }
